from xml.dom.minidom import Element


cdef class Frame:

    def __init__(self, name: str, root: Element):
        self.lexicalUnits = []
        self.name = name
        for lexicalUnit in root:
            self.lexicalUnits.append(LexicalUnit(lexicalUnit.attrib["ID"], lexicalUnit))

    cpdef LexicalUnit getLexicalUnit(self, int index):
        return self.lexicalUnits[index]

    cpdef int size(self):
        return len(self.lexicalUnits)

    cpdef str getName(self):
        return self.name



from xml.dom.minidom import Element


cdef class LexicalUnit:

    def __init__(self, id: str, root: Element):
        self.frameElements = []
        self.synSetId = id
        for element in root:
            self.frameElements.append(element.text)

    cpdef int size(self):
        return len(self.frameElements)

    cpdef list getFrameElements(self):
        return self.frameElements



from FrameNet.LexicalUnit cimport LexicalUnit


cdef class Frame:

    cdef str name
    cdef list lexicalUnits

    cpdef LexicalUnit getLexicalUnit(self, int index)
    cpdef int size(self)
    cpdef str getName(self)



from distutils.core import setup
from Cython.Build import cythonize

setup(
    ext_modules=cythonize(["FrameNet/*.pyx"],
                          compiler_directives={'language_level': "3"}),
    name='NlpToolkit-FrameNet-Cy',
    version='1.0.1',
    packages=['FrameNet'],
    package_data={'FrameNet': ['*.pxd', '*.pyx', '*.c', '*.py']},
    url='https://github.com/StarlangSoftware/TurkishFrameNet-Cy',
    license='',
    author='olcaytaner',
    author_email='olcaytaner@isikun.edu.tr',
    description='FrameNet library'
)



import os
import xml.etree.ElementTree
from FrameNet.Frame cimport Frame


cdef class FrameNet:

    cdef list frames

    def __init__(self, directory="../Frames/"):
        self.frames = []
        for r, d, f in os.walk(directory):
            for file in f:
                root = xml.etree.ElementTree.parse(os.path.join(r, file)).getroot()
                self.frames.append(Frame(file, root))

    cpdef int size(self):
        return len(self.frames)

    cpdef Frame getFrame(self, int index):
        return self.frames[index]
